@@ -1,4 +1,4 @@
-/* $Id: glibtop.h,v 1.36 2004/09/25 19:31:18 bdejean Exp $ */
+/* $Id: glibtop.h,v 1.38 2005/02/15 12:48:32 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -26,11 +26,31 @@
 
 typedef struct _glibtop		glibtop;
 
+/**
+ *  LIBGTOP_CHECK_VERSION
+ *  @major: Major version number
+ *  @minor: Minor version number
+ *  @micro: Micro version number
+ *
+ *  Checks if the version given is compatable with this version of the
+ *  library.  For example, LIBGTOP_CHECK_VERSION(1.2.3) would return TRUE
+ *  if the version is 1.2.5, and FALSE if 1.1.0.  This can be used in
+ *  build tests.
+ *
+ **/
+
+#include <libgtopconfig.h>
+
+#define LIBGTOP_CHECK_VERSION(major, minor, micro)    \
+(LIBGTOP_MAJOR_VERSION > (major) || \
+(LIBGTOP_MAJOR_VERSION == (major) && LIBGTOP_MINOR_VERSION > (minor)) || \
+(LIBGTOP_MAJOR_VERSION == (major) && LIBGTOP_MINOR_VERSION == (minor) && \
+LIBGTOP_MICRO_VERSION >= (micro)))
+
 
 #include <glibtop/global.h>
 
 #include <glibtop_server.h>
-#include <glibtop/types.h>
 
 #ifdef HAVE_GLIBTOP_MACHINE_H
 #include <glibtop_machine.h>
