@@ -1,4 +1,4 @@
-/* $Id: procsegment.h,v 1.23 2003/10/20 15:19:39 hadess Exp $ */
+/* $Id: procsegment.h,v 1.25 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -46,7 +46,7 @@ typedef struct _glibtop_proc_segment	glibtop_proc_segment;
 
 struct _glibtop_proc_segment
 {
-	u_int64_t	flags,
+	guint64	flags,
 		text_rss,	/* text resident set size */
 		shlib_rss,	/* shared-lib resident set size */
 		data_rss,	/* data resident set size */
@@ -76,16 +76,6 @@ void glibtop_init_proc_segment_s (glibtop *server);
 void glibtop_get_proc_segment_s (glibtop *server, glibtop_proc_segment *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_segment [];
-extern const unsigned glibtop_types_proc_segment [];
-extern const char *glibtop_labels_proc_segment [];
-extern const char *glibtop_descriptions_proc_segment [];
-
-#endif
 
 G_END_DECLS
 
