@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.32 2004/06/12 12:50:01 bdejean Exp $ */
+/* $Id: init.c,v 1.34 2005/02/15 12:48:33 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -22,6 +22,7 @@
 */
 
 #include <glibtop.h>
+#include <glibtop/error.h>
 #include <glibtop/sysdeps.h>
 #include <glibtop/parameter.h>
 
@@ -29,7 +30,7 @@
 #define DEFAULT_PORT 42800
 #endif
 
-static glibtop _glibtop_global_server = { .flags = 0 };
+static glibtop _glibtop_global_server = { 0 };
 glibtop *glibtop_global_server = &_glibtop_global_server;
 
 static void
