@@ -1,4 +1,4 @@
-/* $Id: uptime.c,v 1.14 2004/06/09 18:52:21 bdejean Exp $ */
+/* $Id: uptime.c,v 1.16 2004/08/28 20:55:37 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -49,7 +49,7 @@ glibtop_init_uptime_p (glibtop *server)
 void
 glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 {
-#ifdef __NetBSD__
+#if defined(__NetBSD__) || defined(__OpenBSD__)
 	time_t now;
 	time_t uptime;
 	int mib[2];
@@ -68,8 +68,6 @@ glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 		buf->flags = _glibtop_sysdeps_uptime;
 	}
 #else
-	buf->flags = _glibtop_sysdeps_uptime;
-
 	glibtop_cpu cpu;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_UPTIME), 0);
