@@ -22,11 +22,13 @@
 #ifndef __GLIBTOP_SAFEIO_H__
 #define __GLIBTOP_SAFEIO_H__
 
+#include <glib/gmacros.h>
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 int
 s_open(const char *, int);
@@ -43,6 +45,6 @@ s_pread(int, void *, size_t, off_t);
 int
 s_closedir(DIR *);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
-#endif
+#endif /* __GLIBTOP_SAFEIO_H__ */
